//*****************************************************************************
//
// File Name	: 'ad7730.c'
// Title		: AD7730's Library
// Author		: Hamid Rostami, 2008
// Target MCU	: Atmel AVR series
//
// This code is distributed under the GNU Public License
//		which can be found at http://www.gnu.org/licenses/gpl.txt
//
//*****************************************************************************

#include "ad7730.h"

void AD_InitHW(void){
	
	_delay_ms(100);
	
	AD_DDR |= (1<<AD_SCLK_BIT);
	AD_DDR |= (1<<AD_DOUT_BIT);
	AD_DDR |= (1<<AD_RESET_BIT);
	AD_DDR &= ~(1<<AD_DIN_BIT);
	AD_DDR |= (1<<AD_MCLK_BIT);
	
	RESET_LOW;
	DOUT_LOW;
	SCLK_LOW;
	RESET_HIGH;
	
	OCR0 = 1;
	TCCR0 = 0b10011001;
}

// -----------------------------------------------------------------
void AD_readReg24(char regAddr, unsigned int *high, unsigned int *low){
	AD_writeData(regAddr, 8);			// Write to Communication Register
	
	*high = AD_readData(8);
	*low = AD_readData(16);
}

// -----------------------------------------------------------------
unsigned int AD_readReg(char regAddr, char bitNum){
	unsigned int data;
	
	AD_writeData(regAddr, 8);			// Write to Communication Register

	data = AD_readData(bitNum);
	return data;
}

// -----------------------------------------------------------------
void AD_writeReg24(char regAddr, unsigned int high, unsigned int low){
	AD_writeData(regAddr, 8);			// Write to Communication Register
	
	AD_writeData(high, 8);
	AD_writeData(low, 16);
}

// -----------------------------------------------------------------
void AD_writeReg(char regAddr, unsigned int data, char bitNum){
	AD_writeData(regAddr, 8);			// Write to Communication Register
	
	AD_writeData(data, bitNum);
}

// -----------------------------------------------------------------
unsigned int AD_readCont16(void){
	int i;
	unsigned int data = 0;
	
	DOUT_LOW;
	
	for(i=7; i>=0; i--){
		SCLK_HIGH;
		SCLK_LOW;
		
		if( AD_PIN & (1<<AD_DIN_BIT) ){
			data |= (1<<i);
		}else{
			data &= ~(1<<i);
		}
	}
	
	for(i=15; i>=8; i--){
		SCLK_HIGH;
		SCLK_LOW;
		
		if( AD_PIN & (1<<AD_DIN_BIT) ){
			data |= (1<<i);
		}else{
			data &= ~(1<<i);
		}
	}
	
	return data;
}

void AD_stopReadCont(void){
	AD_writeData(AD_REG_w_STOP, 8);
}

// -----------------------------------------------------------------
void AD_writeData(unsigned int data, char bitNum){
	int i;
	
	for(i=bitNum-1; i>=0; i--){
		SCLK_HIGH;
		
		if( data & (1<<i) ){
			DOUT_HIGH;
		}else{
			DOUT_LOW;
		}
		
		SCLK_LOW;
	}
}

// -----------------------------------------------------------------
unsigned int AD_readData(char bitNum){
	int i;
	unsigned int data = 0;
	
	for(i=bitNum-1; i>=0; i--){
		SCLK_HIGH;
		SCLK_LOW;
		
		if( AD_PIN & (1<<AD_DIN_BIT) ){
			data |= (1<<i);
		}else{
			data &= ~(1<<i);
		}
	}
	
	return data;
}
