//*****************************************************************************
//
// File Name	: 'ad7730.h'
// Title		: AD7730's Library
// Author		: Hamid Rostami, 2008
// Target MCU	: Atmel AVR series
//
// This code is distributed under the GNU Public License
//		which can be found at http://www.gnu.org/licenses/gpl.txt
//
//*****************************************************************************

#ifndef AD7730_H
#define AD7730_H

#include "global.h"
#include <avr/io.h>
#include <util/delay.h>


// I/O setting
#define AD_SCLK_BIT 0
#define AD_RESET_BIT 1
#define AD_DOUT_BIT 2
#define AD_MCLK_BIT 3
#define AD_DIN_BIT 4

#define AD_PORT PORTB
#define AD_PIN PINB
#define AD_DDR DDRB

// I/O Marco
#define SCLK_HIGH AD_PORT |= (1<<AD_SCLK_BIT)
#define SCLK_LOW AD_PORT &= ~(1<<AD_SCLK_BIT)
#define DOUT_HIGH AD_PORT |= (1<<AD_DOUT_BIT)
#define DOUT_LOW AD_PORT &= ~(1<<AD_DOUT_BIT)
#define RESET_HIGH AD_PORT |= (1<<AD_RESET_BIT)
#define RESET_LOW AD_PORT &= ~(1<<AD_RESET_BIT)

// Reister's Addresses for Single Read
#define AD_REG_R_STATUS 0x10
#define AD_REG_R_DATA 0x11
#define AD_REG_R_MODE 0x12
#define AD_REG_R_FILTER 0x13
#define AD_REG_R_DAC 0x14
#define AD_REG_R_OFFSET 0x15
#define AD_REG_R_GAIN 0x16
#define AD_REG_R_TEST 0x17
// Reister's Addresses for CONTINUOUS Read
#define AD_REG_RC_STATUS 0x20
#define AD_REG_RC_DATA 0x21
#define AD_REG_RC_MODE 0x22
// Reister's Addresses for Single Write
#define AD_REG_w_STATUS 0x0
#define AD_REG_w_MODE 0x2
#define AD_REG_w_FILTER 0x03
#define AD_REG_w_DAC 0x4
#define AD_REG_w_OFFSET 0x5
#define AD_REG_w_GAIN 0x6
#define AD_REG_w_STOP 0x30

// Public Functions
void AD_InitHW(void);
unsigned int AD_readReg(char regAddr, char bitNum);
void AD_readReg24(char regAddr, unsigned int *high, unsigned int *low);

void AD_writeReg(char regAddr, unsigned int data, char bitNum);
void AD_writeReg24(char regAddr, unsigned int high, unsigned int low);

unsigned int AD_readCont16(void);
void AD_stopReadCont(void);

// Private Functions
void AD_writeData(unsigned int data, char bitNum);
unsigned int AD_readData(char bitNum);

#endif
